# Musipelago
Okay, I'm not great at writing catchy catchphrases or... blorby blurbs, so I'll cut to the point

This has been inspired by the idea of people from Manual discord, where they make manual apworld for artist discographies, where you receive albums as items from other users, and get location checks by listening to songs within them.

This is an implementation of this idea using local files or OpenSubsonic for both creation of a working world from albums or user playlists, and actual interaction with AP and playback using their music catalogue.

This readme is very work in progress, like everything else. Grab the Windows exes from releases or get the project from pip. If installed via pip, commands are `musipelago-gen` and `musipelago-client`

## Acknowledgements & Licenses

### Software
This software is licensed under the MIT License. See [LICENSE](LICENSE) for details.

### Assets
* **Fonts:** [Noto Sans](https://fonts.google.com/noto/specimen/Noto+Sans+JP) by Google.
    * Licensed under the [SIL Open Font License, Version 1.1](src/musipelago/resources/LICENSE-NOTOFONTS.txt).
* **Icons:** [Phosphor Icons](https://phosphoricons.com).
    * Licensed under the [MIT License](src/musipelago/resources/LICENSE-PHOSPHORICONS.txt).